@@ -1,10 +1,25 @@
 package HTTP::Session::State::Cookie;
 use HTTP::Session::State::Base;
-use CGI::Cookie;
 use Carp ();
 
+our $COOKIE_CLASS = 'CGI::Cookie';
+
 __PACKAGE__->mk_ro_accessors(qw/name path domain expires/);
 
+{
+    my $required = 0;
+    sub _cookie_class {
+        my $class = shift;
+        unless ($required) {
+            (my $klass = $COOKIE_CLASS) =~ s!::!/!g;
+            $klass .= ".pm";
+            require $klass;
+            $required++;
+        }
+        return $COOKIE_CLASS
+    }
+}
+
 sub new {
     my $class = shift;
     my %args = ref($_[0]) ? %{$_[0]} : @_;
@@ -17,7 +32,7 @@ sub new {
 sub get_session_id {
     my ($self, $req) = @_;
 
-    my %jar    = CGI::Cookie->parse($ENV{HTTP_COOKIE} || $req->header('Cookie'));
+    my %jar    = _cookie_class()->parse($ENV{HTTP_COOKIE} || $req->header('Cookie'));
     my $cookie = $jar{$self->name};
     return $cookie ? $cookie->value : undef;
 }
@@ -33,7 +48,7 @@ sub header_filter {
     my ($self, $session_id, $res) = @_;
     Carp::croak "missing session_id" unless $session_id;
 
-    my $cookie = CGI::Cookie->new(
+    my $cookie = _cookie_class()->new(
         sub {
             my %options = (
                 -name   => $self->name,
@@ -94,7 +109,7 @@ path.
 =item expires
 
 expire date.e.g. "+3M".
-see also L<CGI::Simple::Cookie>.
+see also L<CGI::Cookie>.
 
     default: undef
 
@@ -116,7 +131,14 @@ for internal use only
 
 =back
 
+=head1 HOW TO USE YOUR OWN CGI::Simple::Cookie?
+
+    use HTTP::Session::State::Cookie;
+    BEGIN {
+    $HTTP::Session::State::Cookie::COOKIE_CLASS = 'CGI/Simple/Cookie.pm';
+    }
+
 =head1 SEE ALSO
 
-L<HTTP::Session>
+L<HTTP::Session>, L<CGI::Cookie>, L<CGI::Simple::Cookie>
 
